@@ -4,10 +4,10 @@ from dataclasses import dataclass
 from typing import Optional
 
 import ctre
-from fast_unit import Unum
+from robotpy_toolkit_7407.unum import Unum
 
 from robotpy_toolkit_7407.motor import PIDMotor
-from robotpy_toolkit_7407.utils.units import rad, rev, s
+from robotpy_toolkit_7407.utils.units import rad, rev, s, radians_per_second, radians_per_second_squared, radians
 
 
 @dataclass
@@ -17,18 +17,25 @@ class TalonConfig:
     k_D: Optional[float] = None
     k_F: Optional[float] = None
     closed_loop_peak_output: Optional[float] = None
-    motion_cruise_velocity: Optional[Unum] = None
-    motion_acceleration: Optional[Unum] = None
+    motion_cruise_velocity: Optional[radians_per_second] = None
+    motion_acceleration: Optional[radians_per_second_squared] = None
     neutral_brake: Optional[bool] = None
     integral_zone: Optional[float] = None
     max_integral_accumulator: Optional[float] = None
 
 
-talon_sensor_unit = rev / 2048
-hundred_ms = s / 10
+talon_sensor_unit = Unum.unit("talon_sensor_u", rev / 2048, "talon sensor unit")
+hundred_ms = Unum.unit("100ms", s / 10, "100 milliseconds")
 talon_sensor_vel_unit = talon_sensor_unit / hundred_ms
 talon_sensor_accel_unit = talon_sensor_vel_unit / s
 
+k_sensor_pos_to_radians = talon_sensor_unit.asNumber(rad)
+k_radians_to_sensor_pos = rad.asNumber(talon_sensor_unit)
+k_sensor_vel_to_rad_per_sec = talon_sensor_vel_unit.asNumber(rad/s)
+k_rad_per_sec_to_sensor_vel = (rad/s).asNumber(talon_sensor_unit/hundred_ms)
+k_sensor_accel_to_rad_per_sec_sq = talon_sensor_accel_unit.asNumber(rad/(s*s))
+k_rad_per_sec_sq_to_sensor_accel = (rad/(s*s)).asNumber(talon_sensor_unit/(s*hundred_ms))
+
 
 class _Talon(PIDMotor):
     _motor: ctre.BaseTalon
@@ -39,23 +46,23 @@ class _Talon(PIDMotor):
         self._config = config
         self._inverted = inverted
 
-    def get_sensor_position(self) -> Unum:
-        return self._motor.getSelectedSensorPosition(0) * talon_sensor_unit
+    def get_sensor_position(self) -> radians:
+        return self._motor.getSelectedSensorPosition(0) * k_sensor_pos_to_radians
 
-    def set_sensor_position(self, pos: Unum):
-        self._motor.setSelectedSensorPosition(pos.as_number(talon_sensor_unit))
+    def set_sensor_position(self, pos: radians):
+        self._motor.setSelectedSensorPosition(pos * k_radians_to_sensor_pos)
 
-    def get_sensor_velocity(self) -> Unum:
-        return self._motor.getSelectedSensorVelocity(0) * talon_sensor_vel_unit
+    def get_sensor_velocity(self) -> radians_per_second:
+        return self._motor.getSelectedSensorVelocity(0) * k_sensor_vel_to_rad_per_sec
 
     def set_raw_output(self, x: float):
         self._motor.set(ctre.ControlMode.PercentOutput, x)
 
-    def set_target_position(self, pos: Unum):
-        self._motor.set(ctre.ControlMode.MotionMagic, pos.as_number(talon_sensor_unit))
+    def set_target_position(self, pos: radians):
+        self._motor.set(ctre.ControlMode.MotionMagic, pos * k_radians_to_sensor_pos)
 
-    def set_target_velocity(self, vel: Unum):
-        self._motor.set(ctre.ControlMode.Velocity, vel.as_number(talon_sensor_vel_unit))
+    def set_target_velocity(self, vel: radians_per_second):
+        self._motor.set(ctre.ControlMode.Velocity, vel * k_rad_per_sec_to_sensor_vel)
 
     def follow(self, master: _Talon):
         self._motor.follow(master._motor)
@@ -74,9 +81,9 @@ class _Talon(PIDMotor):
         if config.closed_loop_peak_output is not None:
             self._motor.configClosedLoopPeakOutput(0, config.closed_loop_peak_output)
         if config.motion_cruise_velocity is not None:
-            self._motor.configMotionCruiseVelocity(config.motion_cruise_velocity.as_number(talon_sensor_vel_unit))
+            self._motor.configMotionCruiseVelocity(config.motion_cruise_velocity * k_rad_per_sec_to_sensor_vel)
         if config.motion_acceleration is not None:
-            self._motor.configMotionAcceleration(config.motion_acceleration.as_number(talon_sensor_accel_unit))
+            self._motor.configMotionAcceleration(config.motion_acceleration * k_rad_per_sec_sq_to_sensor_accel)
         if config.neutral_brake is not None:
             self._motor.setNeutralMode(ctre.NeutralMode.Brake if config.neutral_brake else ctre.NeutralMode.Coast)
         if config.integral_zone is not None:
@@ -130,20 +137,20 @@ class TalonGroup(PIDMotor):
             if idx != self._leader_idx:
                 motor.follow(self.motors[self._leader_idx])
 
-    def get_sensor_position(self) -> Unum:
+    def get_sensor_position(self) -> radians:
         return self.motors[self._leader_idx].get_sensor_position()
 
-    def set_sensor_position(self, pos: Unum):
+    def set_sensor_position(self, pos: radians):
         self.motors[self._leader_idx].set_sensor_position(pos)
 
-    def get_sensor_velocity(self) -> Unum:
+    def get_sensor_velocity(self) -> radians_per_second:
         return self.motors[self._leader_idx].get_sensor_velocity()
 
     def set_raw_output(self, x: float):
         self.motors[self._leader_idx].set_raw_output(x)
 
-    def set_target_position(self, pos: Unum):
+    def set_target_position(self, pos: radians):
         self.motors[self._leader_idx].set_target_position(pos)
 
-    def set_target_velocity(self, vel: Unum):
+    def set_target_velocity(self, vel: radians_per_second):
         self.motors[self._leader_idx].set_target_velocity(vel)
